Class: Google::Apis::TasksV1::Tasks
- Inherits:
-
Object
- Object
- Google::Apis::TasksV1::Tasks
- Includes:
- Core::Hashable, Core::JsonObjectSupport
- Defined in:
- lib/google/apis/tasks_v1/classes.rb,
lib/google/apis/tasks_v1/representations.rb,
lib/google/apis/tasks_v1/representations.rb
Instance Attribute Summary collapse
-
#etag ⇒ String
ETag of the resource.
-
#items ⇒ Array<Google::Apis::TasksV1::Task>
Collection of tasks.
-
#kind ⇒ String
Type of the resource.
-
#next_page_token ⇒ String
Token used to access the next page of this result.
Instance Method Summary collapse
-
#initialize(**args) ⇒ Tasks
constructor
A new instance of Tasks.
-
#update!(**args) ⇒ Object
Update properties of this object.
Constructor Details
#initialize(**args) ⇒ Tasks
Returns a new instance of Tasks.
394 395 396 |
# File 'lib/google/apis/tasks_v1/classes.rb', line 394 def initialize(**args) update!(**args) end |
Instance Attribute Details
#etag ⇒ String
ETag of the resource.
Corresponds to the JSON property etag
377 378 379 |
# File 'lib/google/apis/tasks_v1/classes.rb', line 377 def etag @etag end |
#items ⇒ Array<Google::Apis::TasksV1::Task>
Collection of tasks.
Corresponds to the JSON property items
382 383 384 |
# File 'lib/google/apis/tasks_v1/classes.rb', line 382 def items @items end |
#kind ⇒ String
Type of the resource. This is always "tasks#tasks".
Corresponds to the JSON property kind
387 388 389 |
# File 'lib/google/apis/tasks_v1/classes.rb', line 387 def kind @kind end |
#next_page_token ⇒ String
Token used to access the next page of this result.
Corresponds to the JSON property nextPageToken
392 393 394 |
# File 'lib/google/apis/tasks_v1/classes.rb', line 392 def next_page_token @next_page_token end |
Instance Method Details
#update!(**args) ⇒ Object
Update properties of this object
399 400 401 402 403 404 |
# File 'lib/google/apis/tasks_v1/classes.rb', line 399 def update!(**args) @etag = args[:etag] if args.key?(:etag) @items = args[:items] if args.key?(:items) @kind = args[:kind] if args.key?(:kind) @next_page_token = args[:next_page_token] if args.key?(:next_page_token) end |